AWG Core Module
===============

.. autoclass:: zhinst.toolkit.control.drivers.base.AWGCore
    :members:


Sequence Programs
-----------------

Base Sequence
+++++++++++++

.. autoclass:: zhinst.toolkit.helpers.sequences.Sequence

Simple Sequence
+++++++++++++++

.. autoclass:: zhinst.toolkit.helpers.sequences.SimpleSequence
    :show-inheritance:

Rabi Sequence
+++++++++++++

.. autoclass:: zhinst.toolkit.helpers.sequences.RabiSequence
    :show-inheritance:

T1 Sequence
+++++++++++

.. autoclass:: zhinst.toolkit.helpers.sequences.T1Sequence
    :show-inheritance:


T2 Ramsey Sequence
++++++++++++++++++

.. autoclass:: zhinst.toolkit.helpers.sequences.T2Sequence
    :show-inheritance:

Readout Sequence
++++++++++++++++

.. autoclass:: zhinst.toolkit.helpers.sequences.ReadoutSequence
    :show-inheritance:

Pulsed Spectroscopy Sequence
++++++++++++++++++++++++++++

.. autoclass:: zhinst.toolkit.helpers.sequences.PulsedSpectroscopySequence
    :show-inheritance:

CW Spectroscopy Sequence
++++++++++++++++++++++++

.. autoclass:: zhinst.toolkit.helpers.sequences.CWSpectroscopySequence
    :show-inheritance:


Trigger Sequence
++++++++++++++++

.. autoclass:: zhinst.toolkit.helpers.sequences.TriggerSequence
    :show-inheritance:

Custom Sequence
+++++++++++++++

.. autoclass:: zhinst.toolkit.helpers.sequences.CustomSequence
    :show-inheritance: